package com.navmii.sdksampleapp;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.view.MenuItem;

import androidx.annotation.CheckResult;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.StringRes;
import androidx.annotation.XmlRes;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.FragmentTransaction;
import androidx.preference.PreferenceFragmentCompat;

public class CommonPreferenceActivity extends AppCompatActivity {

    private final static String EXTRA_PREFERENCES_RES_ID = "EXTRA_PREFERENCES_RES_ID";
    private final static String EXTRA_TITLE_RES_ID = "EXTRA_TITLE_RES_ID";

    @NonNull
    @CheckResult
    public static Intent createStartIntent(@NonNull Context context,
                                           @XmlRes int preferencesResId,
                                           @StringRes int titleResId) {
        return new Intent(context, CommonPreferenceActivity.class)
                .putExtra(EXTRA_PREFERENCES_RES_ID, preferencesResId)
                .putExtra(EXTRA_TITLE_RES_ID, titleResId);
    }

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_preference);

        final int preferenceResId = getIntent().getIntExtra(EXTRA_PREFERENCES_RES_ID, 0);
        final int titleResId = getIntent().getIntExtra(EXTRA_TITLE_RES_ID, 0);

        // set up action bar
        if (getSupportActionBar() != null) {
            getSupportActionBar().setDisplayHomeAsUpEnabled(true);
            getSupportActionBar().setDisplayShowHomeEnabled(true);
            getSupportActionBar().setTitle(titleResId);
        }

        // add preference fragment
        getSupportFragmentManager()
                .beginTransaction()
                .replace(R.id.content, CommonPreferenceFragment.newInstance(preferenceResId))
                .setTransition(FragmentTransaction.TRANSIT_FRAGMENT_OPEN)
                .commit();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case android.R.id.home:
                finish();
                return true;
        }

        return super.onOptionsItemSelected(item);
    }

    public static class CommonPreferenceFragment extends PreferenceFragmentCompat {

        private static final String ARG_PREFERENCE_RES_ID = "ARG_PREFERENCE_RES_ID";

        @NonNull
        @CheckResult
        public static CommonPreferenceFragment newInstance(@XmlRes int preferencesResId) {
            final CommonPreferenceFragment fragment = new CommonPreferenceFragment();

            final Bundle bundle = new Bundle();
            bundle.putInt(ARG_PREFERENCE_RES_ID, preferencesResId);

            fragment.setArguments(bundle);
            return fragment;
        }

        @Override
        public void onCreatePreferences(@Nullable Bundle savedInstanceState, String rootKey) {
            final int preferencesResId = getArguments().getInt(ARG_PREFERENCE_RES_ID, 0);
            addPreferencesFromResource(preferencesResId);
        }
    }
}
