package com.navmii.sdksampleapp;

import android.content.Context;
import android.content.SharedPreferences;

import androidx.annotation.NonNull;
import androidx.annotation.StringRes;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * Helper class to create preference change listener to be used when
 * all preference keys are stored as string resources.
 */
public final class PreferenceChangeListener implements SharedPreferences.OnSharedPreferenceChangeListener {

    public static SharedPreferences.OnSharedPreferenceChangeListener create(
            @NonNull Context context,
            @NonNull Collection<Integer> keyIdsToListen,
            @NonNull Callback callback) {

        final Map<String, Integer> keyToKeyIdMap = new HashMap<>(keyIdsToListen.size());
        for (final int keyId : keyIdsToListen) {
            keyToKeyIdMap.put(context.getString(keyId), keyId);
        }

        return new PreferenceChangeListener(keyToKeyIdMap, callback);
    }

    private final Map<String, Integer> keyToKeyIdMap;
    private final Callback callback;

    private PreferenceChangeListener(Map<String, Integer> keyToKeyIdMap,
                                     Callback callback) {
        this.keyToKeyIdMap = keyToKeyIdMap;
        this.callback = callback;
    }

    @Override
    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences, String key) {
        final Integer keyId = keyToKeyIdMap.get(key);
        if (keyId != null) {
            callback.onPreferenceChanged(keyId);
        }
    }

    public interface Callback {
        void onPreferenceChanged(@StringRes int keyId);
    }
}
