package com.navmii.sdksampleapp;

import android.content.Context;
import android.preference.PreferenceManager;

import androidx.annotation.BoolRes;
import androidx.annotation.IntegerRes;
import androidx.annotation.StringRes;

/**
 * Helper class for getting values of preferences,
 * which keys & default values are stored in resource xmls.
 */
public final class PreferenceUtils {

    private PreferenceUtils() {
    }

    public static String getString(Context context,
                                   @StringRes int keyId,
                                   @StringRes int defaultValueId) {
        return PreferenceManager.getDefaultSharedPreferences(context).getString(
                context.getString(keyId),
                context.getString(defaultValueId)
        );
    }

    public static boolean getBoolean(Context context,
                                     @StringRes int keyId,
                                     @BoolRes int defaultValueId) {
        return PreferenceManager.getDefaultSharedPreferences(context).getBoolean(
                context.getString(keyId),
                context.getResources().getBoolean(defaultValueId)
        );
    }

    public static int getInteger(Context context,
                                 @StringRes int keyId,
                                 @IntegerRes int defaultValueId) {

        int defaultValue = context.getResources().getInteger(defaultValueId);

        try {
            return PreferenceManager.getDefaultSharedPreferences(context).getInt(
                    context.getString(keyId),
                    defaultValue
            );
        } catch (ClassCastException e) {
            return Integer.parseInt(PreferenceManager.getDefaultSharedPreferences(context).getString(
                    context.getString(keyId),
                    String.valueOf(defaultValue)
            ));
        }
    }
}
