package com.navmii.sdksampleapp;

import android.content.Context;
import android.content.Intent;
import android.location.Location;
import android.location.LocationManager;
import android.os.Bundle;
import android.view.MenuItem;
import android.view.View;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.navmii.sdk.common.MapCoordinates;
import com.navmii.sdksampleapp.sdk.PlaceInfo;

import java.util.ArrayList;
import java.util.List;

public class SearchResultsActivity extends AppCompatActivity
        implements SearchResultsRecyclerAdapter.OnSearchItemClickListener {

    public static final String EXTRA_RESULT_MAP_COORDINATES = "EXTRA_RESULT_MAP_COORDINATES";

    private static final String EXTRA_SEARCH_COORDINATES = "EXTRA_SEARCH_COORDINATES";
    private static final String EXTRA_PLACES = "EXTRA_PLACES";

    public static Intent createStartIntent(Context context,
                                           MapCoordinates searchCoordinates,
                                           ArrayList<PlaceInfo> places) {
        return new Intent(context, SearchResultsActivity.class)
                .putExtra(EXTRA_SEARCH_COORDINATES, searchCoordinates)
                .putParcelableArrayListExtra(EXTRA_PLACES, places);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_search_results);

        if (getSupportActionBar() != null) {
            getSupportActionBar().setDisplayHomeAsUpEnabled(true);
            getSupportActionBar().setDisplayShowHomeEnabled(true);
        }

        final MapCoordinates searchCoordinates =
                getIntent().getParcelableExtra(EXTRA_SEARCH_COORDINATES);
        final List<PlaceInfo> places = getIntent().getParcelableArrayListExtra(EXTRA_PLACES);

        final Location searchLocation = new Location(LocationManager.GPS_PROVIDER);
        searchLocation.setLatitude(searchCoordinates.getLatitude());
        searchLocation.setLongitude(searchCoordinates.getLongitude());

        final RecyclerView recyclerView = findViewById(R.id.search_results);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        recyclerView.setAdapter(new SearchResultsRecyclerAdapter(searchLocation, places, this));

        findViewById(R.id.no_results_text).setVisibility(
                places.isEmpty() ? View.VISIBLE : View.GONE);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case android.R.id.home:
                finish();
                return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onItemClick(MapCoordinates mapCoordinates) {
        final Intent intent = new Intent().putExtra(EXTRA_RESULT_MAP_COORDINATES, mapCoordinates);

        setResult(RESULT_OK, intent);
        finish();
    }
}
