package com.navmii.sdksampleapp;

import android.location.Location;
import android.location.LocationManager;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.recyclerview.widget.RecyclerView;

import com.navmii.sdk.common.MapCoordinates;
import com.navmii.sdksampleapp.sdk.AddressInfo;
import com.navmii.sdksampleapp.sdk.PlaceInfo;

import java.util.ArrayList;
import java.util.List;

public class SearchResultsRecyclerAdapter extends RecyclerView.Adapter<SearchResultsRecyclerAdapter.SearchResultViewHolder> {

    private final Location searchLocation;
    private final List<PlaceInfo> places = new ArrayList<>();
    private final OnSearchItemClickListener itemClickListener;

    public SearchResultsRecyclerAdapter(Location searchLocation,
                                        List<PlaceInfo> records,
                                        OnSearchItemClickListener listener) {
        this.searchLocation = searchLocation;
        this.places.addAll(records);
        this.itemClickListener = listener;
    }

    @Override
    public SearchResultViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.search_result_item, viewGroup, false);
        return new SearchResultViewHolder(v);
    }

    @Override
    public void onBindViewHolder(SearchResultViewHolder viewHolder, int i) {
        PlaceInfo place = places.get(i);
        AddressInfo address = place.getAddress();

        viewHolder.mapCoordinates = address.getMapCoordinates();

        boolean visibility;

        Location placeLocation = new Location(LocationManager.GPS_PROVIDER);
        placeLocation.setLatitude(viewHolder.mapCoordinates.getLatitude());
        placeLocation.setLongitude(viewHolder.mapCoordinates.getLongitude());
        viewHolder.distanceData.setText(Utils.formatDistance(
                viewHolder.nameData.getContext(),
                Math.round(searchLocation.distanceTo(placeLocation))));

        viewHolder.nameData.setText(place.getName());
        visibility = !TextUtils.isEmpty(place.getName());
        viewHolder.setViewVisibility(viewHolder.nameData, visibility);
        viewHolder.setViewVisibility(viewHolder.nameTitle, visibility);

        viewHolder.typeData.setText(place.getCategory());
        visibility = !TextUtils.isEmpty(place.getCategory());
        viewHolder.setViewVisibility(viewHolder.typeData, visibility);
        viewHolder.setViewVisibility(viewHolder.typeTitle, visibility);

        viewHolder.countryData.setText(address.getCountry());
        visibility = !TextUtils.isEmpty(address.getCountry());
        viewHolder.setViewVisibility(viewHolder.countryData, visibility);
        viewHolder.setViewVisibility(viewHolder.countryTitle, visibility);

        viewHolder.cityData.setText(address.getCity());
        visibility = !TextUtils.isEmpty(address.getCity());
        viewHolder.setViewVisibility(viewHolder.cityData, visibility);
        viewHolder.setViewVisibility(viewHolder.cityTitle, visibility);

        viewHolder.postalCodeData.setText(address.getPostalCode());
        visibility = !TextUtils.isEmpty(address.getPostalCode());
        viewHolder.setViewVisibility(viewHolder.postalCodeData, visibility);
        viewHolder.setViewVisibility(viewHolder.postalCodeTitle, visibility);

        viewHolder.adminHierarchyData.setText(address.getAdminHierarchy());
        visibility = !TextUtils.isEmpty(address.getAdminHierarchy());
        viewHolder.setViewVisibility(viewHolder.adminHierarchyData, visibility);
        viewHolder.setViewVisibility(viewHolder.adminHierarchyTitle, visibility);


        viewHolder.routeNumberData.setText(address.getRouteNumber());
        visibility = !TextUtils.isEmpty(address.getRouteNumber());
        viewHolder.setViewVisibility(viewHolder.routeNumberData, visibility);
        viewHolder.setViewVisibility(viewHolder.routeNumberTitle, visibility);

        viewHolder.streetData.setText(address.getStreet());
        visibility = !TextUtils.isEmpty(address.getStreet());
        viewHolder.setViewVisibility(viewHolder.streetData, visibility);
        viewHolder.setViewVisibility(viewHolder.streetTitle, visibility);


        viewHolder.houseNumberData.setText(address.getHouseNumber());
        visibility = !TextUtils.isEmpty(address.getHouseNumber());
        viewHolder.setViewVisibility(viewHolder.houseNumberData, visibility);
        viewHolder.setViewVisibility(viewHolder.houseNumberTitle, visibility);

    }

    @Override
    public int getItemCount() {
        return places.size();
    }

    class SearchResultViewHolder extends RecyclerView.ViewHolder implements View.OnClickListener {
        private TextView nameTitle;
        private TextView typeTitle;
        private TextView countryTitle;
        private TextView cityTitle;
        private TextView postalCodeTitle;
        private TextView adminHierarchyTitle;
        private TextView routeNumberTitle;
        private TextView streetTitle;
        private TextView houseNumberTitle;

        private TextView distanceData;
        private TextView nameData;
        private TextView typeData;
        private TextView countryData;
        private TextView cityData;
        private TextView postalCodeData;
        private TextView adminHierarchyData;
        private TextView routeNumberData;
        private TextView streetData;
        private TextView houseNumberData;
        private MapCoordinates mapCoordinates;

        public SearchResultViewHolder(View itemView) {
            super(itemView);
            nameTitle = itemView.findViewById(R.id.name_title);
            typeTitle = itemView.findViewById(R.id.type_title);
            countryTitle = itemView.findViewById(R.id.country_title);
            countryTitle = itemView.findViewById(R.id.country_title);
            cityTitle = itemView.findViewById(R.id.city_title);
            postalCodeTitle = itemView.findViewById(R.id.postal_code_title);
            adminHierarchyTitle = itemView.findViewById(R.id.admin_hierarchy_title);
            routeNumberTitle = itemView.findViewById(R.id.route_number_title);
            streetTitle = itemView.findViewById(R.id.street_title);
            houseNumberTitle = itemView.findViewById(R.id.house_number_title);

            distanceData = itemView.findViewById(R.id.distance_data);
            nameData = itemView.findViewById(R.id.name_data);
            typeData = itemView.findViewById(R.id.type_data);
            countryData = itemView.findViewById(R.id.country_data);
            cityData = itemView.findViewById(R.id.city_data);
            postalCodeData = itemView.findViewById(R.id.postal_code_data);
            adminHierarchyData = itemView.findViewById(R.id.admin_hierarchy_data);
            routeNumberData = itemView.findViewById(R.id.route_number_data);
            streetData = itemView.findViewById(R.id.street_data);
            houseNumberData = itemView.findViewById(R.id.house_number_data);

            itemView.setOnClickListener(this);

        }

        void setViewVisibility(View view, boolean visibility) {
            view.setVisibility(visibility ? View.VISIBLE : View.GONE);
        }


        @Override
        public void onClick(View view) {
            if (itemClickListener != null) {
                itemClickListener.onItemClick(mapCoordinates);
            }
        }
    }

    public interface OnSearchItemClickListener {
        void onItemClick(MapCoordinates mapCoordinates);
    }
}
