package com.navmii.sdksampleapp.map;

import android.app.FragmentTransaction;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.preference.ListPreference;
import android.preference.PreferenceFragment;
import android.view.MenuItem;

import androidx.appcompat.app.AppCompatActivity;

import com.navmii.sdksampleapp.R;

import java.util.ArrayList;
import java.util.List;

public class MapPreferenceActivity extends AppCompatActivity {

    private static final String EXTRA_MAP_SCHEMES = "EXTRA_MAP_SCHEMES";

    public static Intent createStartIntent(Context context, List<String> availableMapSchemes) {
        return new Intent(context, MapPreferenceActivity.class)
                .putStringArrayListExtra(EXTRA_MAP_SCHEMES, new ArrayList<>(availableMapSchemes));
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_preference);

        if (getSupportActionBar() != null) {
            getSupportActionBar().setDisplayHomeAsUpEnabled(true);
            getSupportActionBar().setDisplayShowHomeEnabled(true);
            getSupportActionBar().setTitle(R.string.title_mapPreferences);
        }

        getFragmentManager()
                .beginTransaction()
                .replace(R.id.content, MapPreferenceFragment.newInstance(getIntent().getExtras()))
                .setTransition(FragmentTransaction.TRANSIT_FRAGMENT_OPEN)
                .commit();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (item.getItemId() == android.R.id.home) {
            finish();
        }

        return super.onOptionsItemSelected(item);
    }

    public static class MapPreferenceFragment extends PreferenceFragment {

        public static MapPreferenceFragment newInstance(Bundle arguments) {
            MapPreferenceFragment fragment = new MapPreferenceFragment();
            fragment.setArguments(arguments);
            return fragment;
        }

        @Override
        public void onCreate(Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);

            addPreferencesFromResource(R.xml.preferences_map);

            final ListPreference listPreference = (ListPreference) findPreference(
                    getString(R.string.key_map_scheme));

            List<String> mapSchemes = getArguments().getStringArrayList(EXTRA_MAP_SCHEMES);

            String[] entryValues = mapSchemes != null
                    ? mapSchemes.toArray(new String[mapSchemes.size()])
                    : new String[0];

            listPreference.setEntries(entryValues);
            listPreference.setEntryValues(entryValues);
        }

        @Override
        public void onDestroy() {
            super.onDestroy();
        }
    }
}

