package com.navmii.sdksampleapp.navigation;

import androidx.annotation.DrawableRes;

import com.navmii.sdk.routenavigation.DirectionType;
import com.navmii.sdksampleapp.R;

public class DirectionsHelper {
    private static final int DIRECTION_ANGLE_STEP = 30;

    @DrawableRes
    public static int getDirectionDrawableRes(DirectionType directionType, float angle) {
        switch (directionType) {
            case NONE:
                return R.drawable.direction_white_finish;
            case START:
                return R.drawable.direction_white_start;
            case FINISH:
                return R.drawable.direction_white_finish;
            case CONTINUE:
                return R.drawable.direction_white_continue;
            case BEAR_LEFT:
                return R.drawable.direction_white_bearleft;
            case BEAR_RIGHT:
                return R.drawable.direction_white_bearright;
            case KEEP_LEFT:
                return R.drawable.direction_white_keepleft;
            case KEEP_RIGHT:
                return R.drawable.direction_white_keepright;
            case TURN_LEFT:
                return R.drawable.direction_white_turnleft;
            case TURN_RIGHT:
                return R.drawable.direction_white_turnright;
            case U_TURN_LEFT:
                return R.drawable.direction_white_lh_uturn;
            case U_TURN_RIGHT:
                return R.drawable.direction_white_rh_uturn;
            case EXIT_LEFT:
                return R.drawable.direction_white_exitleft;
            case EXIT_RIGHT:
                return R.drawable.direction_white_exitright;
            case JOIN_LEFT:
                return R.drawable.direction_white_joinleft;
            case JOIN_RIGHT:
                return R.drawable.direction_white_joinright;
            case ROUNDABOUT_CLOCKWISE:
                return getClockwiseDrawableRes(angle);
            case ROUNDABOUT_ANTICLOCKWISE:
                return getAntiClockwiseDrawableRes(angle);
            case TAKE_FERRY:
                return R.drawable.direction_white_takeferry;
            case WAYPOINT_REACHED:
                return R.drawable.direction_white_waypointreached;
        }
        return R.drawable.direction_white_finish;
    }

    @DrawableRes
    private static int getClockwiseDrawableRes(float angle) {
        int stepCount = Math.round(angle) / DIRECTION_ANGLE_STEP;
        switch (stepCount) {
            case 0:
            case 1:
                return R.drawable.direction_white_rh_30;
            case 2:
                return R.drawable.direction_white_rh_60;
            case 3:
                return R.drawable.direction_white_rh_90;
            case 4:
                return R.drawable.direction_white_rh_120;
            case 5:
                return R.drawable.direction_white_rh_150;
            case 6:
                return R.drawable.direction_white_rh_180;
            case 7:
                return R.drawable.direction_white_rh_210;
            case 8:
                return R.drawable.direction_white_rh_240;
            case 9:
                return R.drawable.direction_white_rh_270;
            case 10:
                return R.drawable.direction_white_rh_300;
            case 11:
                return R.drawable.direction_white_rh_330;
            default:
                return R.drawable.direction_white_rh_330;
        }
    }

    @DrawableRes
    private static int getAntiClockwiseDrawableRes(float angle) {
        int stepCount = Math.round(angle) / DIRECTION_ANGLE_STEP;
        switch (stepCount) {
            case 0:
            case 1:
                return R.drawable.direction_white_lh_30;
            case 2:
                return R.drawable.direction_white_lh_60;
            case 3:
                return R.drawable.direction_white_lh_90;
            case 4:
                return R.drawable.direction_white_lh_120;
            case 5:
                return R.drawable.direction_white_lh_150;
            case 6:
                return R.drawable.direction_white_lh_180;
            case 7:
                return R.drawable.direction_white_lh_210;
            case 8:
                return R.drawable.direction_white_lh_240;
            case 9:
                return R.drawable.direction_white_lh_270;
            case 10:
                return R.drawable.direction_white_lh_300;
            case 11:
                return R.drawable.direction_white_lh_330;
            default:
                return R.drawable.direction_white_lh_330;
        }
    }
}

