package com.navmii.sdksampleapp.navigation;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.MenuItem;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import androidx.preference.ListPreference;
import androidx.preference.PreferenceFragmentCompat;
import androidx.preference.SeekBarPreference;

import com.navmii.sdk.Sdk;
import com.navmii.sdk.routenavigation.GuidanceOutput;
import com.navmii.sdksampleapp.PreferenceUtils;
import com.navmii.sdksampleapp.R;

import java.util.List;

public class NavigationPreferenceActivity extends AppCompatActivity {

    public static Intent createStartIntent(Context context) {
        return new Intent(context, NavigationPreferenceActivity.class);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_preference);

        if (getSupportActionBar() != null) {
            getSupportActionBar().setDisplayHomeAsUpEnabled(true);
            getSupportActionBar().setDisplayShowHomeEnabled(true);
            getSupportActionBar().setTitle(R.string.title_navigation_preferences);
        }

        getSupportFragmentManager()
                .beginTransaction()
                .replace(R.id.content, NavigationPreferenceFragment.newInstance())
                .commit();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (item.getItemId() == android.R.id.home) {
            finish();
        }

        return super.onOptionsItemSelected(item);
    }

    public static class NavigationPreferenceFragment
            extends PreferenceFragmentCompat
            implements SharedPreferences.OnSharedPreferenceChangeListener {

        public static NavigationPreferenceFragment newInstance() {
            return new NavigationPreferenceFragment();
        }

        @Override
        public void onCreatePreferences(@Nullable Bundle savedInstanceState,
                                        @Nullable String rootKey) {
            addPreferencesFromResource(R.xml.preferences_navigation);

            updateLanguagePreference();
        }

        @Override
        public void onCreate(Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);

            getPreferenceManager().getSharedPreferences()
                    .registerOnSharedPreferenceChangeListener(this);
        }

        @Override
        public void onDestroy() {
            super.onDestroy();

            getPreferenceManager().getSharedPreferences()
                    .unregisterOnSharedPreferenceChangeListener(this);
        }

        @Override
        public void onSharedPreferenceChanged(SharedPreferences sharedPreferences, String key) {
            if (TextUtils.equals(key,
                    getString(R.string.key_navigation_guidanceOutput))) {

                updateLanguagePreference();
            } else if (TextUtils.equals(key, getString(R.string.key_navigation_minRouteWidth)) ||
                    TextUtils.equals(key, getString(R.string.key_navigation_maxRouteWidth))) {

                int minRouteWidth = PreferenceUtils.getInteger(
                        getContext(),
                        R.string.key_navigation_minRouteWidth,
                        R.integer.defaultValue_navigation_minRouteWidth);

                int maxRouteWidth = PreferenceUtils.getInteger(
                        getContext(),
                        R.string.key_navigation_maxRouteWidth,
                        R.integer.defaultValue_navigation_maxRouteWidth);

                if (minRouteWidth > maxRouteWidth) {
                    if (TextUtils.equals(key, getString(R.string.key_navigation_minRouteWidth))) {
                        ((SeekBarPreference) findPreference(getString(R.string.key_navigation_maxRouteWidth)))
                                .setValue(minRouteWidth);
                    } else {
                        ((SeekBarPreference) findPreference(getString(R.string.key_navigation_minRouteWidth)))
                                .setValue(maxRouteWidth);
                    }
                }
            }
        }

        private void updateLanguagePreference() {
            final ListPreference listPreference = (ListPreference) findPreference(
                    getString(R.string.key_navigation_language)
            );

            String guidanceOutputString = PreferenceUtils.getString(
                    getActivity(),
                    R.string.key_navigation_guidanceOutput,
                    R.string.defaultValue_navigation_guidanceOutput
            );

            GuidanceOutput guidanceOutput = NavigationActivity.
                    getGuidanceOutputFromPersistedString(getActivity(), guidanceOutputString);

            if (guidanceOutput == GuidanceOutput.NONE) {
                listPreference.setEnabled(false);
                listPreference.setEntries(new String[]{});
                listPreference.setEntryValues(new String[]{});
            } else {
                listPreference.setEnabled(true);
                List<String> locales = Sdk.getInstance()
                        .getRouteNavigator()
                        .getGuidanceSettings()
                        .getSupportedLocales();

                String[] localeArray = locales.toArray(new String[0]);

                listPreference.setEntries(localeArray);
                listPreference.setEntryValues(localeArray);
            }
        }
    }
}
