package com.navmii.sdksampleapp.places;

import android.app.FragmentTransaction;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.preference.CheckBoxPreference;
import android.preference.PreferenceFragment;
import android.preference.PreferenceScreen;
import android.view.MenuItem;

import androidx.appcompat.app.AppCompatActivity;

import com.navmii.sdksampleapp.R;

import java.util.ArrayList;
import java.util.List;

public class PlacesPreferenceActivity extends AppCompatActivity {

    private static final String EXTRA_CATEGORY_NAMES = "EXTRA_CATEGORY_NAMES";

    public static Intent createStartIntent(Context context, ArrayList<String> categoryNames) {
        return new Intent(context, PlacesPreferenceActivity.class)
                .putStringArrayListExtra(EXTRA_CATEGORY_NAMES, categoryNames);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_preference);

        if (getSupportActionBar() != null) {
            getSupportActionBar().setDisplayHomeAsUpEnabled(true);
            getSupportActionBar().setDisplayShowHomeEnabled(true);
            getSupportActionBar().setTitle(R.string.title_places_preferences);
        }

        ArrayList<String> categoryNames = getIntent().getStringArrayListExtra(EXTRA_CATEGORY_NAMES);

        getFragmentManager()
                .beginTransaction()
                .replace(R.id.content, PlacesPreferenceFragment.newInstance(categoryNames))
                .setTransition(FragmentTransaction.TRANSIT_FRAGMENT_OPEN)
                .commit();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (item.getItemId() == android.R.id.home) {
            finish();
        }

        return super.onOptionsItemSelected(item);
    }

    public static class PlacesPreferenceFragment extends PreferenceFragment {

        private static final String ARG_CATEGORY_NAMES = "ARG_CATEGORY_NAMES";

        public static PlacesPreferenceFragment newInstance(ArrayList<String> categoryNames) {
            final PlacesPreferenceFragment fragment = new PlacesPreferenceFragment();

            final Bundle args = new Bundle();
            args.putStringArrayList(ARG_CATEGORY_NAMES, categoryNames);

            fragment.setArguments(args);

            return fragment;
        }

        @Override
        public void onCreate(Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);

            createPreferenceScreen(getArguments().getStringArrayList(ARG_CATEGORY_NAMES));
        }

        private void createPreferenceScreen(List<String> categoryNames) {
            final PreferenceScreen rootScreen = getPreferenceManager()
                    .createPreferenceScreen(getActivity());

            setPreferenceScreen(rootScreen);

            for (String categoryName : categoryNames) {
                CheckBoxPreference checkBoxPreference = new CheckBoxPreference(getActivity());

                final String key = PlacesActivity
                        .getPoiCategoryPreferenceKey(categoryName);

                final boolean defaultValue = PlacesActivity
                        .getPoiCategoryPreferenceDefaultValue(categoryName);

                checkBoxPreference.setTitle(categoryName);
                checkBoxPreference.setKey(key);
                //noinspection ConstantConditions
                checkBoxPreference.setDefaultValue(defaultValue);


                rootScreen.addPreference(checkBoxPreference);
            }
        }
    }
}
