package com.navmii.sdksampleapp.views;


import android.content.Context;
import android.view.View;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.TextView;

import com.navmii.sdk.routecalculation.Route;
import com.navmii.sdk.routenavigation.Direction;
import com.navmii.sdk.routenavigation.PositionOnRoute;
import com.navmii.sdk.routenavigation.RouteNavigator;
import com.navmii.sdksampleapp.R;
import com.navmii.sdksampleapp.Utils;
import com.navmii.sdksampleapp.navigation.DirectionsHelper;

public class NavigationInfoController {

    private ImageView nextDirectionView;
    private TextView nextDirectionDistanceView;

    private TextView nextRoadView;
    private TextView remainingDistanceView;
    private TextView remainingTimeView;

    private ProgressBar routeProgressBar;

    public NavigationInfoController(View navigationInfoView) {
        nextDirectionView = navigationInfoView.findViewById(R.id.next_direction);
        nextDirectionDistanceView =
                navigationInfoView.findViewById(R.id.next_direction_distance);

        nextRoadView = navigationInfoView.findViewById(R.id.next_road);
        remainingDistanceView = navigationInfoView.findViewById(R.id.remaining_distance);
        remainingTimeView = navigationInfoView.findViewById(R.id.remaining_time);

        routeProgressBar = navigationInfoView.findViewById(R.id.route_progress);
    }

    public boolean update(Route routeInfo, RouteNavigator routeNavigator) {
        PositionOnRoute positionOnRoute = routeNavigator.getPositionOnRoute();

        Context context = nextDirectionView.getContext();

        Direction nextDirection = routeNavigator.getNextDirection();

        if (nextDirection == null) {
            return false;
        }

        nextDirectionView.setImageResource(DirectionsHelper.getDirectionDrawableRes(
                nextDirection.getType(), nextDirection.getRoundaboutAngle()));
        nextDirectionDistanceView.setText(context.getString(
                R.string.distance_in_m, routeNavigator.getDistanceToNextDirectionInMeters()));

        nextRoadView.setText(nextDirection.getRoadTo().getName());

        remainingDistanceView.setText(
                Utils.formatDistance(context, positionOnRoute.getDistanceToDestinationInMeters()));

        remainingTimeView.setText(
                Utils.formatTime(context, positionOnRoute.getTimeToDestinationInSeconds()));

        routeProgressBar.setProgress(Math.round(
                positionOnRoute.getPassedDistanceInMeters() / (float) routeInfo.getLength() * 100));

        return true;
    }

}
