package com.navmii.sdksampleapp.views;

import android.content.Context;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ProgressBar;
import android.widget.TextView;

import androidx.annotation.Nullable;
import androidx.constraintlayout.widget.ConstraintLayout;

import com.navmii.sdk.common.Place;
import com.navmii.sdksampleapp.R;

import java.util.Locale;

public class PlaceInfoView extends ConstraintLayout {
    private TextView nameText;
    private TextView coordinatesText;
    private TextView addressText;
    private ProgressBar loadingProgressBar;

    public PlaceInfoView(Context context) {
        super(context);
        init(context);
    }

    public PlaceInfoView(Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }

    public PlaceInfoView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init(context);
    }

    public PlaceInfoView(Context context, @Nullable AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        init(context);
    }

    public void setPlace(Place place) {
        String name = place.getName();
        nameText.setText(!name.isEmpty() ? name : "-");
        coordinatesText.setText(String.format(Locale.US, "%.6f, %.6f",
                place.getCoordinates().getLatitude(),
                place.getCoordinates().getLongitude()));
        addressText.setText(place.getAddress().getStreet());
    }

    public void setIsLoadingDetails(boolean isLoading) {
        if (isLoading) {
            addressText.setVisibility(GONE);
            loadingProgressBar.setVisibility(VISIBLE);
        } else {
            addressText.setVisibility(VISIBLE);
            loadingProgressBar.setVisibility(GONE);
        }
    }

    private void init(Context context) {
        View rootView = inflate(context, R.layout.view_place_info, this);
        nameText = rootView.findViewById(R.id.name);
        coordinatesText = rootView.findViewById(R.id.coordinates);
        addressText = rootView.findViewById(R.id.address);
        loadingProgressBar = rootView.findViewById(R.id.loading_progress_bar);

        setLayoutParams(new FrameLayout.LayoutParams(
                ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
    }
}
