package com.navmii.sdksampleapp.views;

import android.annotation.SuppressLint;
import android.content.Context;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.recyclerview.widget.RecyclerView;
import androidx.viewpager2.widget.ViewPager2;

import com.google.android.material.tabs.TabLayout;
import com.google.android.material.tabs.TabLayoutMediator;
import com.navmii.sdk.common.Place;
import com.navmii.sdk.map.MapView;
import com.navmii.sdksampleapp.R;

import java.util.ArrayList;
import java.util.List;

public class PlacesSheetView extends ConstraintLayout {
    private ViewPager2 viewPager;
    private TabLayout pageIndicator;
    private PlacesAdapter adapter;
    private Listener listener;

    public interface Listener {
        void loadPlaceDetails(Place place, MapView.PlaceDetailsCallback callback);

        void onPlaceSelected(Place place);
    }

    public PlacesSheetView(Context context) {
        super(context);
        init(context);
    }

    public PlacesSheetView(Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }

    public PlacesSheetView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init(context);
    }

    public PlacesSheetView(Context context, @Nullable AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        init(context);
    }

    public void setListener(Listener value) {
        listener = value;
        adapter.setListener(value);
    }

    public void setPlaces(List<Place> places) {
        viewPager.setCurrentItem(0);
        if (listener != null) {
            listener.onPlaceSelected(places.get(0));
        }
        adapter.setPlaces(places);
        pageIndicator.setVisibility(places.size() > 1 ? VISIBLE : GONE);
    }

    private void init(Context context) {
        View rootView = inflate(context, R.layout.view_places_sheet, this);
        viewPager = rootView.findViewById(R.id.view_pager);
        viewPager.setOffscreenPageLimit(1);
        viewPager.registerOnPageChangeCallback(new OnPageChangeCallback());
        pageIndicator = rootView.findViewById(R.id.page_indicator);
        adapter = new PlacesAdapter();
        viewPager.setAdapter(adapter);
        new TabLayoutMediator(pageIndicator, viewPager, (tab, position) -> {
        }).attach();
    }

    private class OnPageChangeCallback extends ViewPager2.OnPageChangeCallback {
        @Override
        public void onPageSelected(int position) {
            super.onPageSelected(position);
            if (listener != null) {
                listener.onPlaceSelected(adapter.places.get(position));
            }
        }
    }

    private static class PlaceViewHolder extends RecyclerView.ViewHolder {
        PlaceInfoView placeInfoView;
        PlaceDetailsCallback placeDetailsCallback;

        public PlaceViewHolder(@NonNull PlaceInfoView itemView) {
            super(itemView);
            placeInfoView = itemView;
        }

        public void bind(Place place, Listener listener) {
            placeInfoView.setPlace(place);
            if (placeDetailsCallback != null) {
                placeDetailsCallback.cancel();
            }
            placeDetailsCallback = new PlaceDetailsCallback();
            placeInfoView.setIsLoadingDetails(true);
            if (listener != null) {
                listener.loadPlaceDetails(place, placeDetailsCallback);
            }
        }

        private class PlaceDetailsCallback extends MapView.PlaceDetailsCallback {
            @Override
            public void onFinished(@Nullable Place place) {
                placeInfoView.setIsLoadingDetails(false);
                if (place != null) {
                    placeInfoView.setPlace(place);
                }
            }
        }
    }

    private static class PlacesAdapter extends RecyclerView.Adapter<PlaceViewHolder> {
        private Listener listener;
        private List<Place> places = new ArrayList<>();

        public void setListener(Listener value) {
            listener = value;
        }

        @SuppressLint("NotifyDataSetChanged")
        public void setPlaces(List<Place> value) {
            places = value;
            notifyDataSetChanged();
        }

        @NonNull
        @Override
        public PlaceViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
            PlaceInfoView placeInfoView = new PlaceInfoView(parent.getContext());
            return new PlaceViewHolder(placeInfoView);
        }

        @Override
        public void onBindViewHolder(@NonNull PlaceViewHolder holder, int position) {
            holder.bind(places.get(position), listener);
        }

        @Override
        public int getItemCount() {
            return places.size();
        }
    }
}
