package com.navmii.sdksampleapp.views;


import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.Nullable;

import com.navmii.sdk.navigation.NavigationInfo;
import com.navmii.sdk.navigation.NavigationManager;
import com.navmii.sdksampleapp.R;

public class SpeedLimitController {
    private final NavigationManager.NavigationListener navigationListener = new NavigationListener();

    private View speedLimitSign;
    private TextView speedLimitTextView;
    private TextView speedTextView;
    private TextView speedUnitTextView;
    private View rightSpacerForSpeedWithSpeedLimit;
    private int speedKmH;
    private float speedLimitKmH;
    private ViewGroup viewContainer;
    private View rootView;
    private NavigationManager navigationManager;

    public void setNavigationManager(NavigationManager navigationManager) {
        if (this.navigationManager == navigationManager) {
            return;
        }

        if (this.navigationManager != null) {
            this.navigationManager.removeNavigationListener(navigationListener);
        }

        if (navigationManager != null) {
            navigationManager.addNavigationListener(navigationListener);
            setUpRootView();
        }
        this.navigationManager = navigationManager;
    }

    public void setViewContainer(@Nullable ViewGroup viewContainer) {
        this.viewContainer = viewContainer;

        if (viewContainer == null) {
            rootView = null;
            speedLimitSign = null;
            speedLimitTextView = null;
            speedTextView = null;
            speedUnitTextView = null;
            rightSpacerForSpeedWithSpeedLimit = null;
            return;
        }

        setUpRootView();
    }

    private void setUpRootView() {
        viewContainer.removeAllViews();

        rootView = LayoutInflater.from(
                viewContainer.getContext()).inflate(R.layout.speed_limit_control, viewContainer);

        speedLimitSign = rootView.findViewById(R.id.speed_limit_sign);
        speedLimitTextView = rootView.findViewById(R.id.view_speed_limit);
        speedTextView = rootView.findViewById(R.id.view_speed);
        speedUnitTextView = rootView.findViewById(R.id.view_unit);
        rightSpacerForSpeedWithSpeedLimit = rootView.findViewById(
                R.id.right_spacer_for_speed_with_speed_limit);

        if (speedLimitSign == null ||
                speedLimitTextView == null || speedTextView == null ||
                speedUnitTextView == null ||
                rightSpacerForSpeedWithSpeedLimit == null) {

            return;
        }

        updateSpeedView();
        updateSpeedLimitView();
    }


    private void setSpeedLimitActive(boolean active) {
        if (rootView == null) {
            return;
        }

        if (active) {
            speedLimitSign.setVisibility(View.VISIBLE);
            rightSpacerForSpeedWithSpeedLimit.setVisibility(View.VISIBLE);
        } else {
            speedLimitSign.setVisibility(View.GONE);
            rightSpacerForSpeedWithSpeedLimit.setVisibility(View.GONE);
        }
    }

    private void setSpeed(int speedKmH) {
        if (this.speedKmH != speedKmH) {
            this.speedKmH = speedKmH;
            updateSpeedView();
        }
    }

    private void updateSpeedView() {
        String[] valueWithUnit = getFormattedSpeed(speedKmH);
        String value = valueWithUnit[0];
        String unit = valueWithUnit[1];

        if (speedTextView != null) {
            speedTextView.setText(value);
        }

        if (speedUnitTextView != null) {
            speedUnitTextView.setText(unit);
        }
    }

    private void setSpeedLimit(float speedLimitKmH) {
        if (this.speedLimitKmH != speedLimitKmH) {
            this.speedLimitKmH = speedLimitKmH;
            updateSpeedLimitView();
        }
    }

    private void updateSpeedLimitView() {

        String[] valueWithUnit = getFormattedSpeed(speedLimitKmH);
        String value = valueWithUnit[0];

        if (speedLimitTextView != null) {
            speedLimitTextView.setText(value);
        }

        if (TextUtils.isEmpty(value) || value.equals("0")) {
            setSpeedLimitActive(false);
        } else {
            setSpeedLimitActive(true);
        }
    }

    private String[] getFormattedSpeed(float speed) {
        return new String[]{String.valueOf(Math.round(speed)), "km/h"};
    }

    private float getSpeedLimitFromSdkKmH() {
        if (navigationManager == null) {
            return 0;
        }

        NavigationInfo navigationInfo = navigationManager.getNavigationInfo();

        return navigationInfo != null
                ? navigationInfo.getSpeedLimit()
                : 0;
    }

    private class NavigationListener implements NavigationManager.NavigationListener {
        @Override
        public void onNavigationInfoUpdated() {
            setSpeed((int) navigationManager.getNavigationInfo().getCurrentSpeed());
            setSpeedLimit(getSpeedLimitFromSdkKmH());
        }

        @Override
        public void onCountryChanged() {
        }

        @Override
        public void onDemoRouteStarted() {

        }

        @Override
        public void onDemoRouteFinished() {

        }
    }
}
